==> jc-1.4.0.tar.gz: gnu/java/awt/peer/gtk/GtkPanelPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkPanelPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class 4eb180ddb800c38a gnu_java_awt_peer_gtk_GtkContainerPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 279e1438e63fb4c3 gnu_java_awt_peer_gtk_GtkPanelPeer
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkContainerPeer

#include "gnu/java/awt/peer/gtk/GtkContainerPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkPanelPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkPanelPeer_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_Panel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method$_init$7f858abd5fff1c00(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *, struct _jc_java_awt_Panel$object *);

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *);
extern void _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method$handleEvent$db0e2e7973f3405e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *, struct _jc_java_awt_AWTEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method_info$handleEvent$db0e2e7973f3405e;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *);
	void	(*handleEvent$db0e2e7973f3405e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *, struct _jc_java_awt_AWTEvent$object *);
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkContainerPeer$vmethods	gnu_java_awt_peer_gtk_GtkContainerPeer;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods	gnu_java_awt_peer_gtk_GtkPanelPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs	gnu_java_awt_peer_gtk_GtkPanelPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_refs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkPanelPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkPanelPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkPanelPeer_H_ */

==> jc-1.4.5.tar.gz: gnu/java/awt/peer/gtk/GtkPanelPeer.h <==
// public class gnu.java.awt.peer.gtk.GtkPanelPeer

// class file dependencies
// @dep_class b42ad28212d7bec4 gnu_java_awt_peer_gtk_GtkComponentPeer
// @dep_class 4eb180ddb800c38a gnu_java_awt_peer_gtk_GtkContainerPeer
// @dep_class d6f9e33c09f7be67 gnu_java_awt_peer_gtk_GtkGenericPeer
// @dep_class 279e1438e63fb4c3 gnu_java_awt_peer_gtk_GtkPanelPeer
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_java_awt_peer_gtk_GtkContainerPeer

#include "gnu/java/awt/peer/gtk/GtkContainerPeer.h"

#ifndef _JC_gnu_java_awt_peer_gtk_GtkPanelPeer_H_
#define _JC_gnu_java_awt_peer_gtk_GtkPanelPeer_H_

// Forward structure declarations
struct _jc_java_awt_AWTEvent$object;
struct _jc_java_awt_Panel$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs;
typedef struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object;

typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable;
typedef const struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype;

// Constructors
extern void _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method$_init$7f858abd5fff1c00(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *, struct _jc_java_awt_Panel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method$create$0884e1a8654abdda(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method$handleEvent$db0e2e7973f3405e(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method_info$create$0884e1a8654abdda;
extern _jc_method _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$method_info$handleEvent$db0e2e7973f3405e;

// Virtual methods structure
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods {
	void	(*create$0884e1a8654abdda)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *) _JC_JCNI_ATTR;
	void	(*handleEvent$db0e2e7973f3405e)(_jc_env *, struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_java_awt_peer_gtk_GtkGenericPeer$vmethods	gnu_java_awt_peer_gtk_GtkGenericPeer;
	_jc_gnu_java_awt_peer_gtk_GtkComponentPeer$vmethods	gnu_java_awt_peer_gtk_GtkComponentPeer;
	_jc_gnu_java_awt_peer_gtk_GtkContainerPeer$vmethods	gnu_java_awt_peer_gtk_GtkContainerPeer;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vmethods	gnu_java_awt_peer_gtk_GtkPanelPeer;
};

// Vtype
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype {
	_jc_type			type;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs {
    _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_refs	gnu_java_awt_peer_gtk_GtkPanelPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_refs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_refs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_refs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_java_awt_peer_gtk_GtkGenericPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkGenericPeer;
    _jc_gnu_java_awt_peer_gtk_GtkComponentPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkComponentPeer;
    _jc_gnu_java_awt_peer_gtk_GtkContainerPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkContainerPeer;
    _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$sub_nonrefs	gnu_java_awt_peer_gtk_GtkPanelPeer;
};

// Object instance structure
struct _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$object {
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype	*vtype;
	_jc_gnu_java_awt_peer_gtk_GtkPanelPeer$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$vtype _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_awt_peer_gtk_GtkPanelPeer, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_awt_peer_gtk_GtkPanelPeer$class_object;

#endif	/* _JC_gnu_java_awt_peer_gtk_GtkPanelPeer_H_ */
